package com.ruoyi.rocketmq.service.impl;

import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.rocketmq.domain.InitialSwitchInfo;
import com.ruoyi.rocketmq.domain.InitialSwitchInfoTemp;
import com.ruoyi.rocketmq.mapper.InitialSwitchInfoTempMapper;
import com.ruoyi.rocketmq.service.IInitialSwitchInfoTempService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 交换机监控信息Service业务层处理
 * 
 * @author gyt
 * @date 2025-08-26
 */
@Service
@Slf4j
public class InitialSwitchInfoTempServiceImpl implements IInitialSwitchInfoTempService 
{
    @Autowired
    private InitialSwitchInfoTempMapper initialSwitchInfoTempMapper;

    /**
     * 查询交换机监控信息
     * 
     * @param id 交换机监控信息主键
     * @return 交换机监控信息
     */
    @Override
    public InitialSwitchInfoTemp selectInitialSwitchInfoTempById(Long id)
    {
        return initialSwitchInfoTempMapper.selectInitialSwitchInfoTempById(id);
    }

    /**
     * 查询交换机监控信息列表
     * 
     * @param initialSwitchInfoTemp 交换机监控信息
     * @return 交换机监控信息
     */
    @Override
    public List<InitialSwitchInfoTemp> selectInitialSwitchInfoTempList(InitialSwitchInfoTemp initialSwitchInfoTemp)
    {
        return initialSwitchInfoTempMapper.selectInitialSwitchInfoTempList(initialSwitchInfoTemp);
    }

    /**
     * 新增交换机监控信息
     * 
     * @param initialSwitchInfoTemp 交换机监控信息
     * @return 结果
     */
    @Override
    public int insertInitialSwitchInfoTemp(InitialSwitchInfoTemp initialSwitchInfoTemp)
    {
        initialSwitchInfoTemp.setCreateTime(DateUtils.getNowDate());
        return initialSwitchInfoTempMapper.insertInitialSwitchInfoTemp(initialSwitchInfoTemp);
    }

    /**
     * 修改交换机监控信息
     * 
     * @param initialSwitchInfoTemp 交换机监控信息
     * @return 结果
     */
    @Override
    public int updateInitialSwitchInfoTemp(InitialSwitchInfoTemp initialSwitchInfoTemp)
    {
        initialSwitchInfoTemp.setUpdateTime(DateUtils.getNowDate());
        return initialSwitchInfoTempMapper.updateInitialSwitchInfoTemp(initialSwitchInfoTemp);
    }

    /**
     * 批量删除交换机监控信息
     * 
     * @param ids 需要删除的交换机监控信息主键
     * @return 结果
     */
    @Override
    public int deleteInitialSwitchInfoTempByIds(Long[] ids)
    {
        return initialSwitchInfoTempMapper.deleteInitialSwitchInfoTempByIds(ids);
    }

    /**
     * 删除交换机监控信息信息
     * 
     * @param id 交换机监控信息主键
     * @return 结果
     */
    @Override
    public int deleteInitialSwitchInfoTempById(Long id)
    {
        return initialSwitchInfoTempMapper.deleteInitialSwitchInfoTempById(id);
    }
    /**
     * 批量新增交换机流量监控信息
     *
     * @param list 交换机流量监控信息集合
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class, isolation = Isolation.READ_COMMITTED)
    public int batchInsertInitialSwitchInfoTemp(List<InitialSwitchInfo> list) {
        try {
            return initialSwitchInfoTempMapper.batchInsertInitialSwitchInfoTemp(list);
        }catch (Exception e){
            log.error("批量插入交换机信息临时表失败，失败数量：{}", list.size(), e);
            throw new RuntimeException("批量保存失败",e);
        }
    }

    @Override
    public void truncateSwitchInfoTemp(String clientId) {
        initialSwitchInfoTempMapper.truncateSwitchInfoTemp(clientId);
    }
}
