package com.ruoyi.rocketmq.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.rocketmq.domain.InitialSwitchInfoTemp;
import com.ruoyi.rocketmq.service.IInitialSwitchInfoTempService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 交换机监控信息Controller
 * 
 * @author gyt
 * @date 2025-08-26
 */
@RestController
@RequestMapping("/temp")
public class InitialSwitchInfoTempController extends BaseController
{
    @Autowired
    private IInitialSwitchInfoTempService initialSwitchInfoTempService;

    /**
     * 查询交换机监控信息列表
     */
    @RequiresPermissions("rocketmq:temp:list")
    @GetMapping("/list")
    public TableDataInfo list(InitialSwitchInfoTemp initialSwitchInfoTemp)
    {
        startPage();
        List<InitialSwitchInfoTemp> list = initialSwitchInfoTempService.selectInitialSwitchInfoTempList(initialSwitchInfoTemp);
        return getDataTable(list);
    }

    /**
     * 导出交换机监控信息列表
     */
    @RequiresPermissions("rocketmq:temp:export")
    @Log(title = "交换机监控信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, InitialSwitchInfoTemp initialSwitchInfoTemp)
    {
        List<InitialSwitchInfoTemp> list = initialSwitchInfoTempService.selectInitialSwitchInfoTempList(initialSwitchInfoTemp);
        ExcelUtil<InitialSwitchInfoTemp> util = new ExcelUtil<InitialSwitchInfoTemp>(InitialSwitchInfoTemp.class);
        util.exportExcel(response, list, "交换机监控信息数据");
    }

    /**
     * 获取交换机监控信息详细信息
     */
    @RequiresPermissions("rocketmq:temp:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(initialSwitchInfoTempService.selectInitialSwitchInfoTempById(id));
    }

    /**
     * 新增交换机监控信息
     */
    @RequiresPermissions("rocketmq:temp:add")
    @Log(title = "交换机监控信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody InitialSwitchInfoTemp initialSwitchInfoTemp)
    {
        return toAjax(initialSwitchInfoTempService.insertInitialSwitchInfoTemp(initialSwitchInfoTemp));
    }

    /**
     * 修改交换机监控信息
     */
    @RequiresPermissions("rocketmq:temp:edit")
    @Log(title = "交换机监控信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody InitialSwitchInfoTemp initialSwitchInfoTemp)
    {
        return toAjax(initialSwitchInfoTempService.updateInitialSwitchInfoTemp(initialSwitchInfoTemp));
    }

    /**
     * 删除交换机监控信息
     */
    @RequiresPermissions("rocketmq:temp:remove")
    @Log(title = "交换机监控信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(initialSwitchInfoTempService.deleteInitialSwitchInfoTempByIds(ids));
    }
}
